<?php

namespace Drupal\matomo_alert\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a block to alert logged-in users if the Matomo ID is missing.
 *
 * @Block(
 *   id = "matomo_alert_block",
 *   admin_label = @Translation("Matomo Alert Block"),
 *   category = @Translation("Matomo")
 * )
 */
class MatomoAlertBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a new MatomoAlertBlock.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigFactoryInterface $config_factory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];

    // Check if the current user is authenticated.
    $current_user = \Drupal::currentUser();
    if (!$current_user->isAuthenticated()) {
      return $build;
    }

    // Get Matomo configuration.
    $config = $this->configFactory->get('matomo.settings');
    $site_id = $config->get('site_id');

    // Check Site ID and render the template if missing.
    if (empty($site_id)) {
      $build['matomo_alert'] = [
        '#theme' => 'matomo_alert_block',
        '#render_element' => ['#children' => ''], // Añadido para evitar el error de ThemeManager.
        '#attached' => [
          'library' => ['matomo_alert/matomo_alert'],
        ],
        '#cache' => [
          'max-age' => 0, // Disable caching for this block to reflect config changes immediately.
        ],
      ];
    }

    return $build;
  }

}
